@@ -1,17 +1,17 @@
-# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2003 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software 
+# along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 """Decorate a message by sticking the header and footer around it.
@@ -92,14 +92,16 @@ def process(mlist, msg, msgdata):
     elif msg.get_type() == 'multipart/mixed':
         # The next easiest thing to do is just prepend the header and append
         # the footer as additional subparts
-        mimehdr = MIMEText(header, 'plain', lcset)
-        mimeftr = MIMEText(footer, 'plain', lcset)
         payload = msg.get_payload()
         if not isinstance(payload, ListType):
             payload = [payload]
         if footer:
+            mimeftr = MIMEText(footer, 'plain', lcset)
+            mimeftr['Content-Disposition'] = 'inline'
             payload.append(mimeftr)
         if header:
+            mimehdr = MIMEText(header, 'plain', lcset)
+            mimehdr['Content-Disposition'] = 'inline'
             payload.insert(0, mimehdr)
         msg.set_payload(payload)
         wrap = 0
@@ -137,9 +139,11 @@ def process(mlist, msg, msgdata):
     payload = [inner]
     if header:
         mimehdr = MIMEText(header, 'plain', lcset)
+        mimehdr['Content-Disposition'] = 'inline'
         payload.insert(0, mimehdr)
     if footer:
         mimeftr = MIMEText(footer, 'plain', lcset)
+        mimeftr['Content-Disposition'] = 'inline'
         payload.append(mimeftr)
     msg.set_payload(payload)
     del msg['content-type']
