@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -63,6 +63,7 @@ import socket
 import time
 import errno
 import random
+import traceback
 from stat import ST_NLINK, ST_MTIME
 
 # Units are floating-point seconds.
@@ -158,6 +159,13 @@ class LockFile:
         this refreshes the lock (on set locks).
 
     """
+    # BAW: We need to watch out for two lock objects in the same process
+    # pointing to the same lock file.  Without this, if you lock lf1 and do
+    # not lock lf2, lf2.locked() will still return true.  NOTE: this gimmick
+    # probably does /not/ work in a multithreaded world, but we don't have to
+    # worry about that, do we? <1 wink>.
+    COUNTER = 0
+
     def __init__(self, lockfile,
                  lifetime=DEFAULT_LOCK_LIFETIME,
                  withlogging=0):
@@ -172,11 +180,22 @@ class LockFile:
         """
         self.__lockfile = lockfile
         self.__lifetime = lifetime
-        self.__tmpfname = '%s.%s.%d' % (
-            lockfile, socket.gethostname(), os.getpid())
+        # This works because we know we're single threaded
+        self.__counter = LockFile.COUNTER
+        LockFile.COUNTER += 1
+        self.__tmpfname = '%s.%s.%d.%d' % (
+            lockfile, socket.gethostname(), os.getpid(), self.__counter)
         self.__withlogging = withlogging
         self.__logprefix = os.path.split(self.__lockfile)[1]
+        # For transferring ownership across a fork.
+        self.__owned = 1
 	
+    def __repr__(self):
+        return '<LockFile %s: %s [%s: %ssec] pid=%s>' % (
+            id(self), self.__lockfile,
+            self.locked() and 'locked' or 'unlocked',
+            self.__lifetime, os.getpid())
+
     def set_lifetime(self, lifetime):
         """Set a new lock lifetime.
 
@@ -201,7 +220,7 @@ class LockFile:
             self.set_lifetime(newlifetime)
         # Do we have the lock?  As a side effect, this refreshes the lock!
         if not self.locked() and not unconditionally:
-            raise NotLockedError
+            raise NotLockedError, '%s: %s' % (repr(self), self.__read())
 
     def lock(self, timeout=0):
         """Acquire the lock.
@@ -333,7 +352,51 @@ class LockFile:
         self.unlock(unconditionally=1)
 
     def __del__(self):
-        self.finalize()
+        if self.__owned:
+            self.finalize()
+
+    # Use these only if you're transfering ownership to a child process across
+    # a fork.  Use at your own risk, but it should be race-condition safe.
+    # _transfer_to() is called in the parent, passing in the pid of the
+    # child.  _take_possession() is called in the child, and blocks until the
+    # parent has transferred possession to the child.  _disown() is used to
+    # set the __owned flag to 0, and it is a disgusting wart necessary to make
+    # forced lock acquisition work in mailmanctl. :(
+    def _transfer_to(self, pid):
+        # First touch it so it won't get broken while we're fiddling about.
+        self.__touch()
+        # Find out current claim's temp filename
+        winner = self.__read()
+        # Now twiddle ours to the given pid
+        self.__tmpfname = '%s.%s.%d' % (
+            self.__lockfile, socket.gethostname(), pid)
+        # Create a hard link from the global lock file to the temp file.  This
+        # actually does things in reverse order of normal operation because we
+        # know that lockfile exists, and tmpfname better not!
+        os.link(self.__lockfile, self.__tmpfname)
+        # Now update the lock file to contain a reference to the new owner
+        self.__write()
+        # Toggle off our ownership of the file so we don't try to finalize it
+        # in our __del__()
+        self.__owned = 0
+        # Unlink the old winner, completing the transfer
+        os.unlink(winner)
+        # And do some sanity checks
+        assert self.__linkcount() == 2
+        assert self.locked()
+        self.__writelog('transferred the lock')
+
+    def _take_possession(self):
+        self.__tmpfname = tmpfname = '%s.%s.%d' % (
+            self.__lockfile, socket.gethostname(), os.getpid())
+        # Wait until the linkcount is 2, indicating the parent has completed
+        # the transfer.
+        while self.__linkcount() <> 2 or self.__read() <> tmpfname:
+            time.sleep(0.25)
+        self.__writelog('took possession of the lock')
+
+    def _disown(self):
+        self.__owned = 0
 
     #
     # Private interface
@@ -341,7 +404,9 @@ class LockFile:
 
     def __writelog(self, msg):
         if self.__withlogging:
-            _get_logfile().write('%s %s\n' % (self.__logprefix, msg))
+            logf = _get_logfile()
+            logf.write('%s %s\n' % (self.__logprefix, msg))
+            traceback.print_stack(file=logf)
 
     def __write(self):
         # Make sure it's group writable
@@ -359,7 +424,7 @@ class LockFile:
             filename = fp.read()
             fp.close()
             return filename
-        except (OSError, IOError), e:
+        except EnvironmentError, e:
             if e.errno <> errno.ENOENT: raise
             return None
 
@@ -471,7 +536,7 @@ def _seed():
         fp = open('/dev/random')
         d = fp.read(40)
         fp.close()
-    except (IOError, OSError), e:
+    except EnvironmentError, e:
         if e.errno <> errno.ENOENT:
             raise
         import sha
